@@ -13,15 +13,26 @@ use Scalar::Util;
 
 my %apps; # psgi file to $app mapping
 
+sub preload {
+    my $class = shift;
+    for my $app (@_) {
+        $class->load_app($app);
+    }
+}
+
+sub load_app {
+    my($class, $app) = @_;
+    return $apps{$app} ||= do {
+        local $ENV{MOD_PERL}; # trick Catalyst/CGI.pm etc.
+        Plack::Util::load_psgi $app;
+    };
+}
+
 sub handler {
     my $r = shift;
 
     my $psgi = $r->dir_config('psgi_app');
-
-    my $app = $apps{$psgi} ||= do {
-        delete $ENV{MOD_PERL}; # trick Catalyst/CGI.pm etc.
-        Plack::Util::load_psgi $psgi;
-    };
+    my $app = __PACKAGE__->load_app($psgi);
 
     $r->subprocess_env; # let Apache create %ENV for us :)
 
@@ -88,6 +99,11 @@ Plack::Server::Apache2 - Apache 2.0 handlers to run PSGI application
   PerlSetVar psgi_app /path/to/app.psgi
   </Location>
 
+  <Perl>
+  use Plack::Server::Apache2;
+  Plack::Server::Apache2->preload("/path/to/app.psgi");
+  </Perl>
+
 =head1 AUTHOR
 
 Tatsuhiko Miyagawa
